package de.jsfpraxis.cdi.extension;

import java.util.LinkedHashSet;
import java.util.Set;

import javax.ejb.Startup;
import javax.enterprise.context.ApplicationScoped;
import javax.enterprise.event.Observes;
import javax.enterprise.inject.spi.AfterDeploymentValidation;
import javax.enterprise.inject.spi.Bean;
import javax.enterprise.inject.spi.BeanManager;
import javax.enterprise.inject.spi.Extension;
import javax.enterprise.inject.spi.ProcessBean;

/**
 * Extension for eagerly instantiating @ApplicationScoped beans
 * annotated @Startup, i.e. mimics same EJB annotation semantics.
 * 
 * <p>
 * It is of course possible to define an own @Startup annotation, if desired.
 * 
 * <p>
 * To understand this example completely have a look into the service loader file <code>javax.enterprise.inject.spi.Extension</code>
 * 
 * <p>
 * Copied from https://gist.github.com/mojavelinux/635719
 * 
 * @author Bernd Müller
 *
 */
public class StartupBeanExtension implements Extension {

	private final Set<Bean<?>> startupBeans = new LinkedHashSet<Bean<?>>();

	<X> void processBean(@Observes ProcessBean<X> event) {
		if (event.getAnnotated().isAnnotationPresent(Startup.class) && event.getAnnotated().isAnnotationPresent(ApplicationScoped.class)) {
			startupBeans.add(event.getBean());
		}
	}

	void afterDeploymentValidation(@Observes AfterDeploymentValidation event, BeanManager manager) {
		for (Bean<?> bean : startupBeans) {
			// the call to toString() is a cheat to force the bean to be initialized
			manager.getReference(bean, bean.getBeanClass(), manager.createCreationalContext(bean)).toString();
		}
	}

}
